import { type ValidationArgs } from "@vuelidate/core";
import { type Component } from "vue";
export type FormBuilderModel = {
    [key: string]: boolean | string | number | Date | string[];
};
export interface FormElementItem<Props, FieldProps, Model> {
    key: string;
    props: () => Props;
    formFieldProps?: () => FieldProps;
    validation?: (model: Model) => ValidationArgs;
    formFieldComponent?: Component;
    component: Component;
    isReadOnly?: (model: Model) => boolean;
    isHidden?: (model: Model) => boolean;
    mandatory?: boolean;
}
export interface FormElementSection<Props, FieldProps, Model> {
    title: string;
    description?: string;
    elements: FormElementItem<Props, FieldProps, Model>[];
    component?: Component;
}
export interface FormElement<Props, FieldProps, Model> {
    sets: FormElementSection<Props, FieldProps, Model>[];
}
export type FormElementError = {
    [key: string]: {
        [key: string]: string;
    };
};
export interface FormOptions<Model> {
    validation?: (model: Model) => ValidationArgs;
    isReadOnly?: (model: Model) => boolean;
    isHidden?: (model: Model) => boolean;
    mandatory?: boolean;
}
